==> pim-sieve-editor-17.03.90.tar.xz: pim-sieve-editor-17.03.90/src/sieveeditoremptytabwidgetlabel.h <==
/*
   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

/*
  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.

*/

#ifndef SIEVEEDITOREMPTYTABWIDGETLABEL_H
#define SIEVEEDITOREMPTYTABWIDGETLABEL_H

#include <QLabel>

class SieveEditorEmptyTabWidgetLabel : public QLabel
{
    Q_OBJECT
public:
    explicit SieveEditorEmptyTabWidgetLabel(QWidget *parent = nullptr);
    ~SieveEditorEmptyTabWidgetLabel();

private:
    void init();
};

#endif // SIEVEEDITOREMPTYTABWIDGETLABEL_H

==> pim-sieve-editor_17.12.3.orig.tar.xz: pim-sieve-editor-17.12.3/src/sieveeditoremptytabwidgetlabel.h <==
/*
   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

/*
  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.

*/

#ifndef SIEVEEDITOREMPTYTABWIDGETLABEL_H
#define SIEVEEDITOREMPTYTABWIDGETLABEL_H

#include <QLabel>
#include <QVector>

class SieveEditorEmptyTabWidgetLabel : public QLabel
{
    Q_OBJECT
public:
    explicit SieveEditorEmptyTabWidgetLabel(QWidget *parent = nullptr);
    ~SieveEditorEmptyTabWidgetLabel();

private:
    struct placeHolderTextInfo {
        placeHolderTextInfo()
        {
        }

        placeHolderTextInfo(const QString &t, const QString &info)
            : text(t)
            , menuInfo(info)
        {
        }

        QString text;
        QString menuInfo;
    };

    void addInfo(QString &placeholderText, const QVector<placeHolderTextInfo> &map);
    void init();
};

#endif // SIEVEEDITOREMPTYTABWIDGETLABEL_H
